@@ -174,8 +174,8 @@ class Viewer(ViewerParent):
     _model_name = Unicode('ViewerModel').tag(sync=True)
     _view_module = Unicode('itkwidgets').tag(sync=True)
     _model_module = Unicode('itkwidgets').tag(sync=True)
-    _view_module_version = Unicode('^0.18.0').tag(sync=True)
-    _model_module_version = Unicode('^0.18.0').tag(sync=True)
+    _view_module_version = Unicode('^0.19.0').tag(sync=True)
+    _model_module_version = Unicode('^0.19.0').tag(sync=True)
     image = ITKImage(default_value=None, allow_none=True, help="Image to visualize.").tag(sync=False, **itkimage_serialization)
     rendered_image = ITKImage(default_value=None, allow_none=True).tag(sync=True, **itkimage_serialization)
     _rendering_image = CBool(default_value=False, help="We are currently volume rendering the image.").tag(sync=True)
@@ -185,11 +185,13 @@ class Viewer(ViewerParent):
     slicing_planes = CBool(default_value=False, help="Display the slicing planes in volume rendering view mode.").tag(sync=True)
     gradient_opacity = CFloat(default_value=0.2, help="Volume rendering gradient opacity, from (0.0, 1.0]").tag(sync=True)
     roi = NDArray(dtype=np.float64, default_value=np.zeros((2, 3), dtype=np.float64),
-                help="Region of interest: ((lower_x, lower_y, lower_z), (upper_x, upper_y, upper_z))")\
+                help="Region of interest: [[lower_x, lower_y, lower_z), (upper_x, upper_y, upper_z]]")\
             .tag(sync=True, **array_serialization)\
             .valid(shape_constraints(2, 3))
+    vmin = CFloat(default_value=None, allow_none=True, help="Value that maps to the minimum of image colormap.").tag(sync=True)
+    vmax = CFloat(default_value=None, allow_none=True, help="Value that maps to the maximum of image colormap.").tag(sync=True)
     _largest_roi = NDArray(dtype=np.float64, default_value=np.zeros((2, 3), dtype=np.float64),
-                help="Largest possible region of interest: ((lower_x, lower_y, lower_z), (upper_x, upper_y, upper_z))")\
+                help="Largest possible region of interest: [[lower_x, lower_y, lower_z), (upper_x, upper_y, upper_z]]")\
             .tag(sync=True, **array_serialization)\
             .valid(shape_constraints(2, 3))
     select_roi = CBool(default_value=False, help="Enable an interactive region of interest widget for the image.").tag(sync=True)
@@ -225,6 +227,10 @@ class Viewer(ViewerParent):
     rotate = CBool(default_value=False, help="Rotate the camera around the scene.").tag(sync=True)
     annotations = CBool(default_value=True, help="Show annotations.").tag(sync=True)
     mode = CaselessStrEnum(('x', 'y', 'z', 'v'), default_value='v', help="View mode: x: x plane, y: y plane, z: z plane, v: volume rendering").tag(sync=True)
+    camera = NDArray(dtype=np.float32, default_value=np.zeros((3, 3), dtype=np.float32),
+                help="Camera parameters: [[position_x, position_y, position_z], [focal_point_x, focal_point_y, focal_point_z], [view_up_x, view_up_y, view_up_z]]")\
+            .tag(sync=True, **array_serialization)\
+            .valid(shape_constraints(3, 3))
 
 
     def __init__(self, **kwargs):
@@ -425,10 +431,10 @@ class Viewer(ViewerParent):
     def _on_point_sets_changed(self, change=None):
         # Make sure we have a sufficient number of colors
         old_colors = self.point_set_colors
-        self.point_set_colors = old_colors
+        self.point_set_colors = old_colors[:len(self.point_sets)]
         # Make sure we have a sufficient number of opacities
         old_opacities = self.point_set_opacities
-        self.point_set_opacities = old_opacities
+        self.point_set_opacities = old_opacities[:len(self.point_sets)]
 
     @validate('geometry_colors')
     def _validate_geometry_colors(self, proposal):
@@ -463,10 +469,10 @@ class Viewer(ViewerParent):
     def _on_geometries_changed(self, change=None):
         # Make sure we have a sufficient number of colors
         old_colors = self.geometry_colors
-        self.geometry_colors = old_colors
+        self.geometry_colors = old_colors[:len(self.geometries)]
         # Make sure we have a sufficient number of opacities
         old_opacities = self.geometry_opacities
-        self.geometry_opacities = old_opacities
+        self.geometry_opacities = old_opacities[:len(self.geometries)]
 
     def roi_region(self):
         """Return the itk.ImageRegion corresponding to the roi."""
@@ -545,6 +551,14 @@ def view(image=None,
     shadow: bool, optional, default: True
         Use shadowing in the volume rendering.
 
+    vmin: float, optional, default: None
+        Value that maps to the minimum of image colormap. Defaults to minimum of
+        the image pixel buffer.
+
+    vmax: float, optional, default: None
+        Value that maps to the minimum of image colormap. Defaults to maximum of
+        the image pixel buffer.
+
     Point Sets
     ^^^^^^^^^^
 
@@ -593,6 +607,12 @@ def view(image=None,
             'z': z-plane
             'v': volume rendering
 
+    camera: 3x3 numpy float32 array, optional
+        Camera parameters:
+            [[position_x,    position_y,    position_z],
+             [focal_point_x, focal_point_y, focal_point_z],
+             [view_up_x,     view_up_y,     view_up_z]]
+
 
     Other Parameters
     ----------------
